@@ -5,8 +5,7 @@ use Time::Piece; # for strptime
 use File::Basename ();
 use Path::Class ();
 
-use vars qw($VERSION);
-$VERSION= '0.07';
+our $VERSION= '0.08';
 
 sub new {
     my( $class, %options) = @_;
@@ -110,7 +109,7 @@ sub extractToFileNamed {
 =head1 REPOSITORY
 
 The public repository of this module is 
-L<http://github.com/Corion/archive-sevenzip>.
+L<https://github.com/Corion/archive-sevenzip>.
 
 =head1 SUPPORT
 
@@ -129,7 +128,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2015-2016 by Max Maischein C<corion@cpan.org>.
+Copyright 2015-2019 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
